import sys
import argparse
import re
import json
from urllib.parse import urlencode
from urllib.request import urlopen

site_url = 'https://www.metal-archives.com/'
url_search_songs = 'search/ajax-advanced/searching/songs?'
url_lyrics = 'release/ajax-view-lyrics/id/'
lyrics_not_available = '(lyrics not available)'
lyric_id_re = re.compile(r'id=.+[a-z]+.(?P<id>\d+)')
band_name_re = re.compile(r'title="(?P<name>.*)\"')
tags_re = re.compile(r'<[^>]+>')

def get_songs_data(band_name, song_title):
    """Search on metal-archives for song coincidences"""
    params = dict(bandName = band_name, songTitle = song_title)
    url = site_url + url_search_songs + urlencode(params)
    return json.load(urlopen(url))['aaData']

def get_lyrics_by_song_id(song_id):
    """Search on metal-archives for lyrics based on song_id"""
    url = site_url + url_lyrics + song_id
    return tags_re.sub('', urlopen(url).read().strip().decode())

def iterate_songs_and_print(songs):
    '''Iterate over returned song matches. If the lyrics are different than\
    "(lyrics not available)" then break the loop and print them out.\
    Otherwise the last song of the list will be printed.'''
    for song in songs:
        band_name = band_name_re.search(song[0]).group("name")
        song_title = song[3]
        song_id = lyric_id_re.search(song[4]).group("id")
        lyrics = get_lyrics_by_song_id(song_id)
        if lyrics != lyrics_not_available:
            break

    return lyrics


#----------------------------------------------------------------------
def get_lyrics(artist, album, title):
    """"""
    songs_data = get_songs_data(artist, title)

    if len(songs_data):
        return iterate_songs_and_print(songs_data)
    else:
        return None




import os
from urllib.parse import quote_plus
import time

import dbus
import requests
from bs4 import BeautifulSoup
from colorama import init
from termcolor import colored

from .metrolyrics import get_lyrics as metrolyrics
from .metallum import get_lyrics as metallum

init()

#----------------------------------------------------------------------
def get_current_song():
    """"""
    session_bus = dbus.SessionBus()
    spotify_bus = session_bus.get_object("org.mpris.MediaPlayer2.spotify", "/org/mpris/MediaPlayer2")
    spotify_properties = dbus.Interface(spotify_bus, "org.freedesktop.DBus.Properties")
    metadata = spotify_properties.Get("org.mpris.MediaPlayer2.Player", "Metadata")

    try:
        artist = metadata['xesam:artist'][0].title()
        title =  metadata['xesam:title']
        album = metadata['xesam:album']
        return artist, album, title
    except:
        return None

#----------------------------------------------------------------------
def print_lyrics(artist, album, title, lyrics, source):
    """"""

    W = 70
    center = lambda l:l.ljust(W//2+len(l)//2, ' ').rjust(W, ' ')
    write = lambda text, color, on_color, attr: print(colored(center(text), color, on_color, attr))


    write(title, 'white', 'on_red', ['bold'])
    write('{}-{}'.format(artist, album), 'white', 'on_red', ['reverse'])
    print(center('[{}]'.format(source)))
    print('\n')
    if lyrics:
        for line in  lyrics.split('\n'):
            write(line, 'white', None, [])


current_song = None
while True:
    try:
        if current_song != get_current_song():
            current_song = get_current_song()

            lyrics = metallum(*current_song)
            source = "The Metal Archives"
            if not lyrics:
                lyrics = metrolyrics(*current_song)
                source = "MetroLyrics"

            os.system('clear')
            print_lyrics(*current_song, lyrics, source)
    except:
        time.sleep(15)
    time.sleep(5)


#!/usr/bin/python3

from setuptools import setup, find_packages

setup(name = "metallum",
      version = "0.3",
      description = "Console current lyrics visualizer",
      #description_file = "README.rst",

      author = "",
      author_email = "",
      maintainer = "Yeison Cardona",
      maintainer_email = "yeisoneng@gmail.com",

      url = "http://yeisoncardona.com",
      download_url = "",

      license = "GPLv3",
      keywords = "Spotify, lyrics, metallum",

      #classifiers=[#list of classifiers in https://pypi.python.org/pypi?:action=list_classifiers
                   #"Environment :: X11 Applications :: Qt",
                   #"Intended Audience :: Developers",
                   #"License :: OSI Approved :: GNU General Public License v2 (GPLv2)",
                   #"Operating System :: POSIX :: Linux",
                   #"Operating System :: Microsoft :: Windows",
                   #"Operating System :: MacOS",
                   #"Programming Language :: Python",
                   #"Topic :: Software Development",
                   #"Topic :: Software Development :: Code Generators",
                   #"Topic :: Software Development :: Compilers",
                   #"Topic :: Software Development :: Debuggers",
                   #],

      packages = find_packages(),
      include_package_data = True,

      install_requires = [
                          "bs4",
                          "requests",
                          #"gitpython",
                          #"hgapi",
                          #"pyusb==1.0.0b2",
                          #"setuptools",
                          #"wheel"
                          #"pyside",
                          ],
      scripts = [
                 "cmd/metallum",
                 ],

      zip_safe = False,

      )



import dbus
import requests
from bs4 import BeautifulSoup
import os
from urllib.parse import quote_plus
import time



#----------------------------------------------------------------------
def get_lyrics(artis, album, title):
    """"""
    song_name = '{}, {}, {}'.format(artis, album, title)

    song_name += ' metrolyrics'
    name = quote_plus(song_name)
    hdr = {'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.11'
           '(KHTML, like Gecko) Chrome/23.0.1271.64 Safari/537.11',
           'Accept-Language': 'en-US,en;q=0.8',
           'Connection': 'keep-alive'}

    url = 'http://www.google.com/search?q=' + name

    result = requests.get(url, headers=hdr).text
    link_start = result.find('http://www.metrolyrics.com')

    if(link_start == -1):
        #return("Lyrics not found on Metrolyrics")
        return None

    link_end = result.find('html', link_start + 1)
    link = result[link_start:link_end + 4]


    lyrics_html = requests.get(link, headers={
                               'User-Agent': 'Mozilla/5.0 (Macintosh; Intel'
                               'Mac OS X 10_12_1) AppleWebKit/537.36 (KHTML, '
                               'like Gecko) Chrome/55.0.2883.95 Safari/537.36'
                               }
                               ).text

    soup = BeautifulSoup(lyrics_html, "lxml")
    raw_lyrics = (soup.findAll('p', attrs={'class': 'verse'}))
    paras = []
    try:
        final_lyrics = unicode.join(u'\n', map(unicode, raw_lyrics))
    except NameError:
        final_lyrics = str.join(u'\n', map(str, raw_lyrics))

    final_lyrics = (final_lyrics.replace('<p class="verse">', '\n'))
    final_lyrics = (final_lyrics.replace('<br/>', ' '))
    final_lyrics = final_lyrics.replace('</p>', ' ')
    return final_lyrics


